@@ -12,7 +12,7 @@ use File::Spec::Functions qw(catfile catdir splitdir);
 use vars qw($VERSION @Pagers $Bindir $Pod2man
   $Temp_Files_Created $Temp_File_Lifetime
 );
-$VERSION = '3.14_07';
+$VERSION = '3.15_08';
 #..........................................................................
 
 BEGIN {  # Make a DEBUG constant very first thing...
@@ -239,14 +239,14 @@ sub usage {
   $! = 0;
   
   die <<EOF;
-perldoc [options] PageName|ModuleName|ProgramName...
+perldoc [options] PageName|ModuleName|ProgramName|URL...
 perldoc [options] -f BuiltinFunction
 perldoc [options] -q FAQRegex
 perldoc [options] -v PerlVariable
 
 Options:
     -h   Display this help message
-    -V   report version
+    -V   Report version
     -r   Recursive search (slow)
     -i   Ignore case
     -t   Display pod using pod2text instead of pod2man and nroff
@@ -263,16 +263,17 @@ Options:
     -M FormatterModuleNameToUse
     -w formatter_option:option_value
     -L translation_code   Choose doc translation (if any)
-    -X   use index if present (looks for pod.idx at $Config{archlib})
+    -X   Use index if present (looks for pod.idx at $Config{archlib})
     -q   Search the text of questions (not answers) in perlfaq[1-9]
     -f   Search Perl built-in functions
     -v   Search predefined Perl variables
 
-PageName|ModuleName...
+PageName|ModuleName|ProgramName|URL...
          is the name of a piece of documentation that you want to look at. You
          may either give a descriptive name of the page (as in the case of
          `perlfunc') the name of a module, either like `Term::Info' or like
-         `Term/Info', or the name of a program, like `perldoc'.
+         `Term/Info', or the name of a program, like `perldoc', or a URL 
+         starting with http(s). 
 
 BuiltinFunction
          is the name of a perl function.  Will extract documentation from
@@ -292,18 +293,27 @@ EOF
 
 #..........................................................................
 
-sub usage_brief {
-  my $me = $0;		# Editing $0 is unportable
+sub program_name {
+  my $me = $0;  # Editing $0 is unportable
 
   $me =~ s,.*[/\\],,; # get basename
-  
+
+  return $me;
+}
+
+#..........................................................................
+
+sub usage_brief {
+  my $self = shift;
+  my $me = $self->program_name;
+
   die <<"EOUSAGE";
 Usage: $me [-h] [-V] [-r] [-i] [-D] [-t] [-u] [-m] [-n nroffer_program] [-l] [-T] [-d output_filename] [-o output_format] [-M FormatterModuleNameToUse] [-w formatter_option:option_value] [-L translation_code] [-F] [-X] PageName|ModuleName|ProgramName
        $me -f PerlFunc
        $me -q FAQKeywords
-       $me -A PerlVar
+       $me -v PerlVar
 
-The -h option prints more help.  Also try "perldoc perldoc" to get
+The -h option prints more help.  Also try "$me perldoc" to get
 acquainted with the system.                        [Perldoc v$VERSION]
 EOUSAGE
 
@@ -484,7 +494,7 @@ sub find_good_formatter_class {
       
     } elsif(
       (IS_VMS or IS_MSWin32 or IS_Dos or IS_OS2)
-       # the alway case-insensitive fs's
+       # the always case-insensitive filesystems
       and $class_seen{lc("~$c")}++
     ) {
       DEBUG > 4 and print
@@ -499,7 +509,7 @@ sub find_good_formatter_class {
       } else {
         $^W = 0;
         # The average user just has no reason to be seeing
-        #  $^W-suppressable warnings from the the require!
+        #  $^W-suppressible warnings from the the require!
       }
 
       eval "require $c";
@@ -549,10 +559,11 @@ sub formatter_sanity_check {
      ) || '';
     $ext = ".$ext" if length $ext;
     
+    my $me = $self->program_name;
     die
        "When using Perldoc to format with $formatter_class, you have to\n"
      . "specify -T or -dsomefile$ext\n"
-     . "See `perldoc perldoc' for more information on those switches.\n"
+     . "See `$me perldoc' for more information on those switches.\n"
     ;
   }
 }
@@ -658,8 +669,18 @@ sub options_processing {
     $self->opt_n("nroff") unless $self->opt_n;
     $self->add_formatter_option( '__nroffer' => $self->opt_n );
 
+    # Get language from PERLDOC_POD2 environment variable
+    if ( ! $self->opt_L && $ENV{PERLDOC_POD2} ) {
+        if ( $ENV{PERLDOC_POD2} eq '1' ) {
+          $self->_elem('opt_L',(split(/\_/, $ENV{LC_ALL} || $ENV{LC_LANG} || $ENV{LANG}))[0] );
+        }
+        else {
+          $self->_elem('opt_L', $ENV{PERLDOC_POD2});
+        }
+    };
+
     # Adjust for using translation packages
-    $self->add_translator($self->opt_L) if $self->opt_L;
+    $self->add_translator(split(/\s+/,$self->opt_L)) if $self->opt_L;
 
     return;
 }
@@ -683,15 +704,15 @@ sub options_sanity {
     
     # Any sanity-checking need doing here?
     
-    # But does not make sense to set either -f or -q in $ENV{"PERLDOC"} 
-    if( $self->opt_f or $self->opt_q ) { 
-	$self->usage("Only one of -f -or -q") if $self->opt_f and $self->opt_q;
-	warn 
-	    "Perldoc is only really meant for reading one word at a time.\n",
-	    "So these parameters are being ignored: ",
-	    join(' ', @{$self->{'args'}}),
-	    "\n"
-		if @{$self->{'args'}}
+    # But does not make sense to set either -f or -q in $ENV{"PERLDOC"}
+    if( $self->opt_f or $self->opt_q ) {
+    $self->usage("Only one of -f -or -q") if $self->opt_f and $self->opt_q;
+    warn
+        "Perldoc is only really meant for reading one word at a time.\n",
+        "So these parameters are being ignored: ",
+        join(' ', @{$self->{'args'}}),
+        "\n"
+        if @{$self->{'args'}}
     }
     return;
 }
@@ -702,6 +723,24 @@ sub grand_search_init {
     my($self, $pages, @found) = @_;
 
     foreach (@$pages) {
+        if (/^http(s)?:\/\//) {
+            require HTTP::Tiny;
+            require File::Temp;
+            my $response = HTTP::Tiny->new->get($_);
+            if ($response->{success}) {
+                my ($fh, $filename) = File::Temp::tempfile(UNLINK => 1);
+                $fh->print($response->{content});
+                push @found, $filename;
+                ($self->{podnames}{$filename} =
+                  m{.*/([^/#?]+)} ? uc $1 : "UNKNOWN")
+                   =~ s/\.P(?:[ML]|OD)\z//;
+            }
+            else {
+                print STDERR "No " .
+                    ($self->opt_m ? "module" : "documentation") . " found for \"$_\".\n";                
+            }
+            next;
+        }
         if ($self->{'podidx'} && open(PODIDX, $self->{'podidx'})) {
             my $searchfor = catfile split '::', $_;
             $self->aside( "Searching for '$searchfor' in $self->{'podidx'}\n" );
@@ -736,7 +775,7 @@ sub grand_search_init {
                 for ($i = 0; $trn = $ENV{'DCL$PATH;'.$i}; $i++) {
                     push(@searchdirs,$trn);
                 }
-                push(@searchdirs,'perl_root:[lib.pod]')  # installed pods
+                push(@searchdirs,'perl_root:[lib.pods]')  # installed pods
             }
             else {
                 push(@searchdirs, grep(-d, split($Config{path_sep},
@@ -748,7 +787,7 @@ sub grand_search_init {
             $self->aside( "Found as @files\n" );
         }
         # add "perl" prefix, so "perldoc foo" may find perlfoo.pod
-	elsif (BE_LENIENT and !/\W/ and  @files = $self->searchfor(0, "perl$_", @searchdirs)) {
+    elsif (BE_LENIENT and !/\W/ and  @files = $self->searchfor(0, "perl$_", @searchdirs)) {
             $self->aside( "Loosely found as @files\n" );
         }
         else {
@@ -763,12 +802,13 @@ sub grand_search_init {
                     ($self->opt_m ? "module" : "documentation") . " found for \"$_\".\n";
                 if ( @{ $self->{'found'} } ) {
                     print STDERR "However, try\n";
+                    my $me = $self->program_name;
                     for my $dir (@{ $self->{'found'} }) {
                         opendir(DIR, $dir) or die "opendir $dir: $!";
                         while (my $file = readdir(DIR)) {
                             next if ($file =~ /^\./s);
                             $file =~ s/\.(pm|pod)\z//;  # XXX: badfs
-                            print STDERR "\tperldoc $_\::$file\n";
+                            print STDERR "\t$me $_\::$file\n";
                         }
                         closedir(DIR)    or die "closedir $dir: $!";
                     }
@@ -801,7 +841,7 @@ sub maybe_generate_dynamic_pod {
         push @{ $self->{'temp_file_list'} }, $buffer;
          # I.e., it MIGHT be deleted at the end.
         
-	my $in_list = $self->opt_f || $self->opt_v;
+    my $in_list = $self->opt_f || $self->opt_v;
 
         print $buffd "=over 8\n\n" if $in_list;
         print $buffd @dynamic_pod  or die "Can't print $buffer: $!";
@@ -844,7 +884,7 @@ sub new_translator { # $tr = $self->new_translator($lang);
     my $pack = 'POD2::' . uc($lang);
     eval "require $pack";
     if ( !$@ && $pack->can('new') ) {
-	return $pack->new();
+    return $pack->new();
     }
 
     eval { require POD2::Base };
@@ -890,7 +930,7 @@ sub search_perlvar {
     open(PVAR, "<", $perlvar)               # "Funk is its own reward"
         or die("Can't open $perlvar: $!");
 
-    if ( $opt =~ /^\$\d+$/ ) { # handle $1, $2, ..., $9
+    if ( $opt ne '$0' && $opt =~ /^\$\d+$/ ) { # handle $1, $2, ...
       $opt = '$<I<digits>>';
     }
     my $search_re = quotemeta($opt);
@@ -920,18 +960,19 @@ sub search_perlvar {
         elsif (!/^\s+$/) { # not a blank line
             if ( $found ) {
                 $inheader = 0; # don't accept more =item (unless inlist)
-	    }
+        }
             else {
                 @$pod = (); # reset
                 $inheader = 1; # start over
                 next;
             }
-	}
+    }
 
         if (/^=over/) {
             ++$inlist;
         }
         elsif (/^=back/) {
+            last if $found && !$inheader && !$inlist;
             --$inlist;
         }
         push @$pod, $_;
@@ -965,7 +1006,9 @@ sub search_perlfunc {
      print "Going to perlfunc-scan for $search_re in $perlfunc\n";
 
     my $re = 'Alphabetical Listing of Perl Functions';
-    if ( $self->opt_L ) {
+
+    # Check available translator or backup to default (english)
+    if ( $self->opt_L && defined $self->{'translators'}->[0] ) {
         my $tr = $self->{'translators'}->[0];
         $re =  $tr->search_perlfunc_re if $tr->can('search_perlfunc_re');
     }
@@ -991,6 +1034,7 @@ sub search_perlfunc {
             ++$inlist;
         }
         elsif (/^=back/) {
+            last if $found > 1 and not $inlist;
             --$inlist;
         }
         push @$pod, $_;
@@ -1100,6 +1144,11 @@ sub render_findings {
   $self->{'output_is_binary'} =
     $formatter->can('write_with_binmode') && $formatter->write_with_binmode;
 
+  if( $self->{podnames} and exists $self->{podnames}{$file} and
+      $formatter->can('name') ) {
+    $formatter->name($self->{podnames}{$file});
+  }
+
   my ($out_fh, $out) = $self->new_output_file(
     ( $formatter->can('output_extension') && $formatter->output_extension )
      || undef,
@@ -1114,7 +1163,7 @@ sub render_findings {
     } else {
       $^W = 0;
       # The average user just has no reason to be seeing
-      #  $^W-suppressable warnings from the formatting!
+      #  $^W-suppressible warnings from the formatting!
     }
           
     eval {  $formatter->parse_from_file( $file, $out_fh )  };
@@ -1289,7 +1338,7 @@ sub after_rendering_MSWin32  {
 }
 
 #..........................................................................
-#	:	:	:	:	:	:	:	:	:
+#   :   :   :   :   :   :   :   :   :
 #..........................................................................
 
 
@@ -1304,55 +1353,55 @@ sub minus_f_nocase {   # i.e., do like -f, but without regard to case
         or IS_Dos or IS_OS2
      ) {
         # On a case-forgiving file system, or if case is important,
-	#  that is it, all we can do.
-	warn "Ignored $path: unreadable\n" if -f _;
-	return '';
+    #  that is it, all we can do.
+    warn "Ignored $path: unreadable\n" if -f _;
+    return '';
      }
      
      local *DIR;
      my @p = ($dir);
      my($p,$cip);
      foreach $p (splitdir $file){
-	my $try = catfile @p, $p;
+    my $try = catfile @p, $p;
         $self->aside("Scrutinizing $try...\n");
-	stat $try;
- 	if (-d _) {
- 	    push @p, $p;
-	    if ( $p eq $self->{'target'} ) {
-		my $tmp_path = catfile @p;
-		my $path_f = 0;
-		for (@{ $self->{'found'} }) {
-		    $path_f = 1 if $_ eq $tmp_path;
-		}
-		push (@{ $self->{'found'} }, $tmp_path) unless $path_f;
-		$self->aside( "Found as $tmp_path but directory\n" );
-	    }
- 	}
-	elsif (-f _ && -r _) {
- 	    return $try;
- 	}
-	elsif (-f _) {
-	    warn "Ignored $try: unreadable\n";
- 	}
-	elsif (-d catdir(@p)) {  # at least we see the containing directory!
- 	    my $found = 0;
- 	    my $lcp = lc $p;
- 	    my $p_dirspec = catdir(@p);
- 	    opendir DIR, $p_dirspec  or die "opendir $p_dirspec: $!";
- 	    while(defined( $cip = readdir(DIR) )) {
- 		if (lc $cip eq $lcp){
- 		    $found++;
- 		    last; # XXX stop at the first? what if there's others?
- 		}
- 	    }
- 	    closedir DIR  or die "closedir $p_dirspec: $!";
- 	    return "" unless $found;
+    stat $try;
+    if (-d _) {
+        push @p, $p;
+        if ( $p eq $self->{'target'} ) {
+        my $tmp_path = catfile @p;
+        my $path_f = 0;
+        for (@{ $self->{'found'} }) {
+            $path_f = 1 if $_ eq $tmp_path;
+        }
+        push (@{ $self->{'found'} }, $tmp_path) unless $path_f;
+        $self->aside( "Found as $tmp_path but directory\n" );
+        }
+    }
+    elsif (-f _ && -r _) {
+        return $try;
+    }
+    elsif (-f _) {
+        warn "Ignored $try: unreadable\n";
+    }
+    elsif (-d catdir(@p)) {  # at least we see the containing directory!
+        my $found = 0;
+        my $lcp = lc $p;
+        my $p_dirspec = catdir(@p);
+        opendir DIR, $p_dirspec  or die "opendir $p_dirspec: $!";
+        while(defined( $cip = readdir(DIR) )) {
+        if (lc $cip eq $lcp){
+            $found++;
+            last; # XXX stop at the first? what if there's others?
+        }
+        }
+        closedir DIR  or die "closedir $p_dirspec: $!";
+        return "" unless $found;
 
- 	    push @p, $cip;
- 	    my $p_filespec = catfile(@p);
- 	    return $p_filespec if -f $p_filespec and -r _;
-	    warn "Ignored $p_filespec: unreadable\n" if -f _;
- 	}
+        push @p, $cip;
+        my $p_filespec = catfile(@p);
+        return $p_filespec if -f $p_filespec and -r _;
+        warn "Ignored $p_filespec: unreadable\n" if -f _;
+    }
      }
      return "";
 }
@@ -1415,21 +1464,21 @@ sub page_module_file {
 
     if ($self->{'output_to_stdout'}) {
         $self->aside("Sending unpaged output to STDOUT.\n");
-	local $_;
-	my $any_error = 0;
+    local $_;
+    my $any_error = 0;
         foreach my $output (@found) {
-	    unless( open(TMP, "<", $output) ) {    # XXX 5.6ism
-	      warn("Can't open $output: $!");
-	      $any_error = 1;
-	      next;
-	    }
-	    while (<TMP>) {
-	        print or die "Can't print to stdout: $!";
-	    } 
-	    close TMP  or die "Can't close while $output: $!";
-	    $self->unlink_if_temp_file($output);
-	}
-	return $any_error; # successful
+        unless( open(TMP, "<", $output) ) {    # XXX 5.6ism
+          warn("Can't open $output: $!");
+          $any_error = 1;
+          next;
+        }
+        while (<TMP>) {
+            print or die "Can't print to stdout: $!";
+        }
+        close TMP  or die "Can't close while $output: $!";
+        $self->unlink_if_temp_file($output);
+    }
+    return $any_error; # successful
     }
 
     foreach my $pager ( $self->pagers ) {
@@ -1486,11 +1535,11 @@ sub check_file {
     }
     
     if ($self->opt_m) {
-	return $self->minus_f_nocase($dir,$file);
+    return $self->minus_f_nocase($dir,$file);
     }
     
     else {
-	my $path = $self->minus_f_nocase($dir,$file);
+    my $path = $self->minus_f_nocase($dir,$file);
         if( length $path and $self->containspod($path) ) {
             DEBUG > 3 and print
               "  The file $path indeed looks promising!\n";
@@ -1529,14 +1578,14 @@ sub containspod {
     }
 
     local($_);
-    open(TEST,"<", $file) 	or die "Can't open $file: $!";   # XXX 5.6ism
+    open(TEST,"<", $file)   or die "Can't open $file: $!";   # XXX 5.6ism
     while (<TEST>) {
-	if (/^=head/) {
-	    close(TEST) 	or die "Can't close $file: $!";
-	    return 1;
-	}
+    if (/^=head/) {
+        close(TEST)     or die "Can't close $file: $!";
+        return 1;
     }
-    close(TEST) 		or die "Can't close $file: $!";
+    }
+    close(TEST)         or die "Can't close $file: $!";
     return 0;
 }
 
@@ -1641,13 +1690,13 @@ sub page {  # apply a pager to the output file
     my ($self, $output, $output_to_stdout, @pagers) = @_;
     if ($output_to_stdout) {
         $self->aside("Sending unpaged output to STDOUT.\n");
-	open(TMP, "<", $output)  or  die "Can't open $output: $!"; # XXX 5.6ism
-	local $_;
-	while (<TMP>) {
-	    print or die "Can't print to stdout: $!";
-	} 
-	close TMP  or die "Can't close while $output: $!";
-	$self->unlink_if_temp_file($output);
+    open(TMP, "<", $output)  or  die "Can't open $output: $!"; # XXX 5.6ism
+    local $_;
+    while (<TMP>) {
+        print or die "Can't print to stdout: $!";
+    }
+    close TMP  or die "Can't close while $output: $!";
+    $self->unlink_if_temp_file($output);
     } else {
         # On VMS, quoting prevents logical expansion, and temp files with no
         # extension get the wrong default extension (such as .LIS for TYPE)
@@ -1664,9 +1713,9 @@ sub page {  # apply a pager to the output file
             if (IS_VMS) {
                 last if system("$pager $output") == 0;
             } else {
-	        last if system("$pager \"$output\"") == 0;
+            last if system("$pager \"$output\"") == 0;
             }
-	}
+    }
     }
     return;
 }
@@ -1684,41 +1733,41 @@ sub searchfor {
     my $dir;
     $self->{'target'} = (splitdir $s)[-1];  # XXX: why not use File::Basename?
     for ($i=0; $i<@dirs; $i++) {
-	$dir = $dirs[$i];
-	next unless -d $dir;
-	($dir = VMS::Filespec::unixpath($dir)) =~ s!/\z!! if IS_VMS;
-	if (       (! $self->opt_m && ( $ret = $self->check_file($dir,"$s.pod")))
-		or ( $ret = $self->check_file($dir,"$s.pm"))
-		or ( $ret = $self->check_file($dir,$s))
-		or ( IS_VMS and
-		     $ret = $self->check_file($dir,"$s.com"))
-		or ( IS_OS2 and
-		     $ret = $self->check_file($dir,"$s.cmd"))
-		or ( (IS_MSWin32 or IS_Dos or IS_OS2) and
-		     $ret = $self->check_file($dir,"$s.bat"))
-		or ( $ret = $self->check_file("$dir/pod","$s.pod"))
-		or ( $ret = $self->check_file("$dir/pod",$s))
-		or ( $ret = $self->check_file("$dir/pods","$s.pod"))
-		or ( $ret = $self->check_file("$dir/pods",$s))
-	) {
-	    DEBUG > 1 and print "  Found $ret\n";
-	    return $ret;
-	}
+    $dir = $dirs[$i];
+    next unless -d $dir;
+    ($dir = VMS::Filespec::unixpath($dir)) =~ s!/\z!! if IS_VMS;
+    if (       (! $self->opt_m && ( $ret = $self->check_file($dir,"$s.pod")))
+        or ( $ret = $self->check_file($dir,"$s.pm"))
+        or ( $ret = $self->check_file($dir,$s))
+        or ( IS_VMS and
+             $ret = $self->check_file($dir,"$s.com"))
+        or ( IS_OS2 and
+             $ret = $self->check_file($dir,"$s.cmd"))
+        or ( (IS_MSWin32 or IS_Dos or IS_OS2) and
+             $ret = $self->check_file($dir,"$s.bat"))
+        or ( $ret = $self->check_file("$dir/pod","$s.pod"))
+        or ( $ret = $self->check_file("$dir/pod",$s))
+        or ( $ret = $self->check_file("$dir/pods","$s.pod"))
+        or ( $ret = $self->check_file("$dir/pods",$s))
+    ) {
+        DEBUG > 1 and print "  Found $ret\n";
+        return $ret;
+    }
 
-	if ($recurse) {
-	    opendir(D,$dir)	or die "Can't opendir $dir: $!";
-	    my @newdirs = map catfile($dir, $_), grep {
-		not /^\.\.?\z/s and
-		not /^auto\z/s  and   # save time! don't search auto dirs
-		-d  catfile($dir, $_)
-	    } readdir D;
-	    closedir(D)		or die "Can't closedir $dir: $!";
-	    next unless @newdirs;
-	    # what a wicked map!
-	    @newdirs = map((s/\.dir\z//,$_)[1],@newdirs) if IS_VMS;
-	    $self->aside( "Also looking in @newdirs\n" );
-	    push(@dirs,@newdirs);
-	}
+    if ($recurse) {
+        opendir(D,$dir) or die "Can't opendir $dir: $!";
+        my @newdirs = map catfile($dir, $_), grep {
+        not /^\.\.?\z/s and
+        not /^auto\z/s  and   # save time! don't search auto dirs
+        -d  catfile($dir, $_)
+        } readdir D;
+        closedir(D)     or die "Can't closedir $dir: $!";
+        next unless @newdirs;
+        # what a wicked map!
+        @newdirs = map((s/\.dir\z//,$_)[1],@newdirs) if IS_VMS;
+        $self->aside( "Also looking in @newdirs\n" );
+        push(@dirs,@newdirs);
+    }
     }
     return ();
 }
@@ -1751,7 +1800,7 @@ sub tweak_found_pathnames {
 }
 
 #..........................................................................
-#	:	:	:	:	:	:	:	:	:
+#   :   :   :   :   :   :   :   :   :
 #..........................................................................
 
 sub am_taint_checking {
@@ -1886,17 +1935,17 @@ Sean M. Burke <sburke@cpan.org>
 #~~~~~~
 #
 # Version 2.05: Sat Oct 12 16:09:00 CEST 2002
-#	Hugo van der Sanden <hv@crypt.org>
-#	Made -U the default, based on patch from Simon Cozens
+#   Hugo van der Sanden <hv@crypt.org>
+#   Made -U the default, based on patch from Simon Cozens
 # Version 2.04: Sun Aug 18 13:27:12 BST 2002
-#	Randy W. Sims <RandyS@ThePierianSpring.org>
-#	allow -n to enable nroff under Win32
+#   Randy W. Sims <RandyS@ThePierianSpring.org>
+#   allow -n to enable nroff under Win32
 # Version 2.03: Sun Apr 23 16:56:34 BST 2000
-#	Hugo van der Sanden <hv@crypt.org>
-#	don't die when 'use blib' fails
+#   Hugo van der Sanden <hv@crypt.org>
+#   don't die when 'use blib' fails
 # Version 2.02: Mon Mar 13 18:03:04 MST 2000
 #       Tom Christiansen <tchrist@perl.com>
-#	Added -U insecurity option
+#   Added -U insecurity option
 # Version 2.01: Sat Mar 11 15:22:33 MST 2000 
 #       Tom Christiansen <tchrist@perl.com>, querulously.
 #       Security and correctness patches.
@@ -1907,33 +1956,33 @@ Sean M. Burke <sburke@cpan.org>
 #
 # Version 1.15: Tue Aug 24 01:50:20 EST 1999
 #       Charles Wilson <cwilson@ece.gatech.edu>
-#	changed /pod/ directory to /pods/ for cygwin
+#   changed /pod/ directory to /pods/ for cygwin
 #         to support cygwin/win32
 # Version 1.14: Wed Jul 15 01:50:20 EST 1998
 #       Robin Barker <rmb1@cise.npl.co.uk>
-#	-strict, -w cleanups
+#   -strict, -w cleanups
 # Version 1.13: Fri Feb 27 16:20:50 EST 1997
 #       Gurusamy Sarathy <gsar@activestate.com>
-#	-doc tweaks for -F and -X options
+#   -doc tweaks for -F and -X options
 # Version 1.12: Sat Apr 12 22:41:09 EST 1997
 #       Gurusamy Sarathy <gsar@activestate.com>
-#	-various fixes for win32
+#   -various fixes for win32
 # Version 1.11: Tue Dec 26 09:54:33 EST 1995
 #       Kenneth Albanowski <kjahds@kjahds.com>
 #   -added Charles Bailey's further VMS patches, and -u switch
 #   -added -t switch, with pod2text support
 #
 # Version 1.10: Thu Nov  9 07:23:47 EST 1995
-#		Kenneth Albanowski <kjahds@kjahds.com>
-#	-added VMS support
-#	-added better error recognition (on no found pages, just exit. On
-#	 missing nroff/pod2man, just display raw pod.)
-#	-added recursive/case-insensitive matching (thanks, Andreas). This
-#	 slows things down a bit, unfortunately. Give a precise name, and
-#	 it'll run faster.
+#       Kenneth Albanowski <kjahds@kjahds.com>
+#   -added VMS support
+#   -added better error recognition (on no found pages, just exit. On
+#    missing nroff/pod2man, just display raw pod.)
+#   -added recursive/case-insensitive matching (thanks, Andreas). This
+#    slows things down a bit, unfortunately. Give a precise name, and
+#    it'll run faster.
 #
-# Version 1.01:	Tue May 30 14:47:34 EDT 1995
-#		Andy Dougherty  <doughera@lafcol.lafayette.edu>
+# Version 1.01: Tue May 30 14:47:34 EDT 1995
+#       Andy Dougherty  <doughera@lafcol.lafayette.edu>
 #   -added pod documentation.
 #   -added PATH searching.
 #   -added searching pod/ subdirectory (mainly to pick up perlfunc.pod
@@ -1943,7 +1992,7 @@ Sean M. Burke <sburke@cpan.org>
 #
 # TODO:
 #
-#	Cache the directories read during sloppy match
+#   Cache the directories read during sloppy match
 #       (To disk, or just in-memory?)
 #
 #       Backport this to perl 5.005?
